summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttSemiSizingControl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdgantt/KDGanttSemiSizingControl.cpp')
-rw-r--r--kdgantt/KDGanttSemiSizingControl.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kdgantt/KDGanttSemiSizingControl.cpp b/kdgantt/KDGanttSemiSizingControl.cpp
index 47d08950..e6258e90 100644
--- a/kdgantt/KDGanttSemiSizingControl.cpp
+++ b/kdgantt/KDGanttSemiSizingControl.cpp
@@ -26,8 +26,8 @@
** licensing are not clear to you.
**
** As a special exception, permission is given to link this program
** with any edition of Qt, and distribute the resulting executable,
** without including the source code for Qt in the source distribution.
**
**********************************************************************/
@@ -57,15 +57,15 @@
orientation and the control arrow button on top of the controlled
widget.
- \param parent the parent widget. This parameter is passed to the
+ \param tqparent the tqparent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
*/
-KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* parent,
+KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* tqparent,
const char* name ) :
- KDGanttSizingControl( parent, name ), _orient( Horizontal ),
+ KDGanttSizingControl( tqparent, name ), _orient( Horizontal ),
_arrowPos( Before ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -78,16 +78,16 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( TQWidget* parent,
the controlled widget (depending on the orientation).
\param orientation the orientation of the splitter
- \param parent the parent widget. This parameter is passed to the
+ \param tqparent the tqparent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
*/
-KDGanttSemiSizingControl::KDGanttSemiSizingControl( Orientation orientation,
- TQWidget* parent,
+KDGanttSemiSizingControl::KDGanttSemiSizingControl( Qt::Orientation orientation,
+ TQWidget* tqparent,
const char* name ) :
- KDGanttSizingControl( parent, name ), _orient( orientation ),
+ KDGanttSizingControl( tqparent, name ), _orient( orientation ),
_arrowPos( Before ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -101,17 +101,17 @@ KDGanttSemiSizingControl::KDGanttSemiSizingControl( Orientation orientation,
\param arrowPosition specifies whether the control arrow button
should appear before or after the controlled widget
\param orientation the orientation of the splitter
- \param parent the parent widget. This parameter is passed to the
+ \param tqparent the tqparent widget. This parameter is passed to the
base class.
\param name the internal widget name. This parameter is passed to
the base class.
*/
KDGanttSemiSizingControl::KDGanttSemiSizingControl( ArrowPosition arrowPosition,
- Orientation orientation,
- TQWidget* parent,
+ Qt::Orientation orientation,
+ TQWidget* tqparent,
const char* name ) :
- KDGanttSizingControl( parent, name ), _orient( orientation ),
+ KDGanttSizingControl( tqparent, name ), _orient( orientation ),
_arrowPos( arrowPosition ), _minimizedWidget(0), _maximizedWidget(0)
{
init();
@@ -290,10 +290,10 @@ void KDGanttSemiSizingControl::setup()
//------------------------------ Setup the button at the correct possition
if ( _arrowPos == After && _orient == Vertical && !isMinimized() ) {
butLayout->addStretch( 1 );
- butLayout->addWidget( _but, 0, Qt::AlignLeft );
+ butLayout->addWidget( _but, 0, TQt::AlignLeft );
}
else {
- butLayout->addWidget( _but, 0, Qt::AlignRight );
+ butLayout->addWidget( _but, 0, TQt::AlignRight );
butLayout->addStretch( 1 );
}
@@ -313,7 +313,7 @@ void KDGanttSemiSizingControl::setup()
************************************************** */
// hack for the usage in KDGantt as pop-up legend widget
// for this purpose,
// the _maximizedWidget must be a child of the parent of this widget
if ( isMinimized() ) {
widget = _minimizedWidget;
@@ -26,8 +26,8 @@
**
** As a special exception, permission is given to link this program
- ** with any edition of Qt, and distribute the resulting executable,
- ** without including the source code for Qt in the source distribution.
+ ** with any edition of TQt, and distribute the resulting executable,
+ ** without including the source code for TQt in the source distribution.
**
**********************************************************************/
@@ -313,7 +313,7 @@ void KDGanttSemiSizingControl::setup()
// hack for the usage in KDGantt as pop-up legend widget
// for this purpose,
- // the _maximizedWidget must be a child of the parent of this widget
+ // the _maximizedWidget must be a child of the tqparent of this widget
if ( isMinimized() ) {
widget = _minimizedWidget;